From 5f44065dc916439e81a3c37a67e08ce524bdfee1 Mon Sep 17 00:00:00 2001
From: Jakob Leben <jleben@videolan.org>
Date: Tue, 3 Nov 2009 02:07:42 +0100
Subject: [PATCH 2/2] Qt4: podcast configuration embedded in playlist window

---
 modules/gui/qt4/components/playlist/panels.hpp     |   20 ++++++
 modules/gui/qt4/components/playlist/playlist.cpp   |    2 +
 .../gui/qt4/components/playlist/playlist_model.cpp |    5 ++
 .../gui/qt4/components/playlist/playlist_model.hpp |    1 +
 modules/gui/qt4/components/playlist/selector.cpp   |    5 ++
 modules/gui/qt4/components/playlist/selector.hpp   |    1 +
 .../gui/qt4/components/playlist/standardpanel.cpp  |   72 ++++++++++++++++++++
 7 files changed, 106 insertions(+), 0 deletions(-)

diff --git a/modules/gui/qt4/components/playlist/panels.hpp b/modules/gui/qt4/components/playlist/panels.hpp
index 8949179..aff7718 100644
--- a/modules/gui/qt4/components/playlist/panels.hpp
+++ b/modules/gui/qt4/components/playlist/panels.hpp
@@ -42,6 +42,7 @@ class QTreeView;
 class PLModel;
 class QPushButton;
 class QKeyEvent;
+class PodcastToolbar;
 
 class PLPanel: public QWidget
 {
@@ -79,9 +80,11 @@ private:
     QPushButton *repeatButton, *randomButton, *addButton, *gotoPlayingButton;
     int currentRootId;
     QSignalMapper *selectColumnsSigMapper;
+    PodcastToolbar *podcastToolbar;
 public slots:
     void removeItem( int );
     virtual void setRoot( playlist_item_t * );
+    void showPodcastToolbar( bool );
 private slots:
     void deleteSelection();
     void handleExpansion( const QModelIndex& );
@@ -93,6 +96,23 @@ private slots:
     void popupAdd();
     void popupSelectColumn( QPoint );
     void toggleColumnShown( int );
+    void addPodcast( QString );
+    void removePodcast( );
+};
+
+class PodcastToolbar : public QWidget
+{
+    Q_OBJECT;
+public:
+    PodcastToolbar();
+signals:
+    void add( QString url );
+    void remove();
+private slots:
+    void addClicked();
+    void removeClicked();
+private:
+    QLineEdit *input;
 };
 
 #endif
diff --git a/modules/gui/qt4/components/playlist/playlist.cpp b/modules/gui/qt4/components/playlist/playlist.cpp
index 96d5012..a3812cc 100644
--- a/modules/gui/qt4/components/playlist/playlist.cpp
+++ b/modules/gui/qt4/components/playlist/playlist.cpp
@@ -79,6 +79,8 @@ PlaylistWidget::PlaylistWidget( intf_thread_t *_p_i ) : p_intf ( _p_i )
     /* Connect the activation of the selector to a redefining of the PL */
     CONNECT( selector, activated( playlist_item_t * ),
              rightPanel, setRoot( playlist_item_t * ) );
+    CONNECT( selector, showPodcastToolbar( bool ),
+             rightPanel, showPodcastToolbar( bool ) );
 
     rightPanel->setRoot( p_root );
 
diff --git a/modules/gui/qt4/components/playlist/playlist_model.cpp b/modules/gui/qt4/components/playlist/playlist_model.cpp
index b991e46..b697814 100644
--- a/modules/gui/qt4/components/playlist/playlist_model.cpp
+++ b/modules/gui/qt4/components/playlist/playlist_model.cpp
@@ -473,6 +473,11 @@ QStringList PLModel::selectedURIs()
     return lst;
 }
 
+QStringList PLModel::selectedURIs( QModelIndexList list  )
+{
+  current_selection = list;
+  return selectedURIs();
+}
 /************************* General playlist status ***********************/
 
 bool PLModel::hasRandom()
diff --git a/modules/gui/qt4/components/playlist/playlist_model.hpp b/modules/gui/qt4/components/playlist/playlist_model.hpp
index 620ea81..af13d39 100644
--- a/modules/gui/qt4/components/playlist/playlist_model.hpp
+++ b/modules/gui/qt4/components/playlist/playlist_model.hpp
@@ -113,6 +113,7 @@ public:
 
     /* Lookups */
     QStringList selectedURIs();
+    QStringList selectedURIs( QModelIndexList );
     bool hasRandom(); bool hasLoop(); bool hasRepeat();
     QModelIndex index( PLItem *, int c ) const;
     QModelIndex currentIndex( ) { return index( currentItem, 0 ); };
diff --git a/modules/gui/qt4/components/playlist/selector.cpp b/modules/gui/qt4/components/playlist/selector.cpp
index fce873d..ec64f40 100644
--- a/modules/gui/qt4/components/playlist/selector.cpp
+++ b/modules/gui/qt4/components/playlist/selector.cpp
@@ -104,6 +104,11 @@ void PLSelector::setSource( QTreeWidgetItem *item )
 
     if( pl_item )
        emit activated( pl_item );
+
+    if( i_type == SD_TYPE && item->data( 0, NAME_ROLE ).toString() == QString("podcast") )
+        emit showPodcastToolbar( true );
+    else
+        emit showPodcastToolbar( false );
 }
 
 void PLSelector::makeStandardItem( QTreeWidgetItem* item, const QString& str )
diff --git a/modules/gui/qt4/components/playlist/selector.hpp b/modules/gui/qt4/components/playlist/selector.hpp
index d842dd1..ce254e8 100644
--- a/modules/gui/qt4/components/playlist/selector.hpp
+++ b/modules/gui/qt4/components/playlist/selector.hpp
@@ -82,6 +82,7 @@ private slots:
     void setSource( QTreeWidgetItem *item );
 signals:
     void activated( playlist_item_t * );
+    void showPodcastToolbar( bool );
 };
 
 #endif
diff --git a/modules/gui/qt4/components/playlist/standardpanel.cpp b/modules/gui/qt4/components/playlist/standardpanel.cpp
index e9279c1..6d0df4c 100644
--- a/modules/gui/qt4/components/playlist/standardpanel.cpp
+++ b/modules/gui/qt4/components/playlist/standardpanel.cpp
@@ -175,8 +175,14 @@ StandardPLPanel::StandardPLPanel( PlaylistWidget *_parent,
     titleFont.setFamily( "Verdana" );
     title->setFont( titleFont );
 
+    podcastToolbar = new PodcastToolbar;
+    CONNECT( podcastToolbar, add( QString ), this, addPodcast( QString ) );
+    CONNECT( podcastToolbar, remove(), this, removePodcast() );
+
     /* Finish the layout */
     layout->addWidget( title );
+    layout->addWidget( podcastToolbar );
+    podcastToolbar->hide();
     layout->addWidget( view );
     layout->addLayout( buttons );
 //    layout->addWidget( bar );
@@ -352,6 +358,43 @@ void StandardPLPanel::deleteSelection()
     model->doDelete( list );
 }
 
+void StandardPLPanel::showPodcastToolbar( bool visible )
+{
+    if( visible ) podcastToolbar->show();
+    else podcastToolbar->hide();
+}
+
+void StandardPLPanel::addPodcast( QString url )
+{
+    vlc_object_t *p_obj = (vlc_object_t*)
+                    vlc_object_find_name( p_intf->p_libvlc,
+                                          "podcast", FIND_CHILD );
+    if( p_obj ) {
+      QString request("ADD:");
+      request += url;
+      var_SetString( p_obj, "podcast-request", qtu( request ) );
+      vlc_object_release( p_obj );
+    }
+}
+
+void StandardPLPanel::removePodcast( )
+{
+    QStringList urls = model->selectedURIs(
+      view->selectionModel()->selectedIndexes() );
+
+    if( urls.isEmpty() ) return;
+
+    vlc_object_t *p_obj = (vlc_object_t*)
+                  vlc_object_find_name( p_intf->p_libvlc,
+                                        "podcast", FIND_CHILD );
+    if( p_obj ) {
+        QString request("RM:");
+        request += urls[0];
+        var_SetString( p_obj, "podcast-request", qtu( request ) );
+        vlc_object_release( p_obj );
+    }
+}
+
 StandardPLPanel::~StandardPLPanel()
 {
     getSettings()->beginGroup("Playlist");
@@ -359,3 +402,32 @@ StandardPLPanel::~StandardPLPanel()
     getSettings()->endGroup();
 }
 
+PodcastToolbar::PodcastToolbar()
+{
+  QHBoxLayout *layout = new QHBoxLayout();
+  QPushButton *btnAdd = new QPushButton( qtr("Add") );
+  QPushButton *btnRemove = new QPushButton( qtr("Remove") );
+  input = new QLineEdit();
+  input->setToolTip( qtr( "Insert the URL of the podcast feed here" ) );
+  layout->addWidget( btnAdd );
+  layout->addWidget( input );
+  layout->addWidget( btnRemove );
+  setLayout( layout );
+  CONNECT( btnAdd, clicked(), this, addClicked() );
+  CONNECT( btnRemove, clicked(), this, removeClicked() );
+}
+
+void PodcastToolbar::addClicked()
+{
+    QString url = input->text();
+    if( !url.isEmpty() )
+    {
+      emit add( url );
+      input->clear();
+    }
+}
+
+void PodcastToolbar::removeClicked()
+{
+    emit remove();
+}
-- 
1.6.3.3

